@@ -1,8 +1,7 @@
 //! # Fixed Bitmaps
 //!
-//! This is a crate whose aim is to create the simplest bitmap structures to work with. Currently there is only the one
-//! bitmap struct to work with, `Bitmap64`, though there are plans to add more in the future. See `Bitmap64` documentation to see
-//! how to use it.
+//! This is a crate whose aim is to create the simplest bitmap structures to work with. This crate provides wrappings for Rust unsigned
+//! integers from u8 up to u128.
 //!
 //! Note that indexing for bit access starts at 0, which allows you to know what the effect of setting a bit will be, by putting 2 to
 //! the power of the index. For example, the following example sets the 5th bit to true in an otherwise empty bitmap. This is equivalent
@@ -30,8 +29,14 @@
 //! }
 //! ```
 
+mod bitmap128;
+mod bitmap16;
+mod bitmap32;
 mod bitmap64;
 mod bitmap8;
 
+pub use bitmap128::Bitmap128;
+pub use bitmap16::Bitmap16;
+pub use bitmap32::Bitmap32;
 pub use bitmap64::Bitmap64;
 pub use bitmap8::Bitmap8;
